@@ -89,7 +89,7 @@ StockDistribution::StockDistribution(CommentStream& infile,
 
   //read in area aggregation from file
   readWordAndValue(infile, "areaaggfile", aggfilename);
-  datafile.open(aggfilename, ios::in);
+  datafile.open(aggfilename, ios::binary);
   handle.checkIfFailure(datafile, aggfilename);
   handle.Open(aggfilename);
   numarea = readAggregation(subdata, areas, areaindex);
@@ -99,7 +99,7 @@ StockDistribution::StockDistribution(CommentStream& infile,
 
   //read in age aggregation from file
   readWordAndValue(infile, "ageaggfile", aggfilename);
-  datafile.open(aggfilename, ios::in);
+  datafile.open(aggfilename, ios::binary);
   handle.checkIfFailure(datafile, aggfilename);
   handle.Open(aggfilename);
   numage = readAggregation(subdata, ages, ageindex);
@@ -109,7 +109,7 @@ StockDistribution::StockDistribution(CommentStream& infile,
 
   //read in length aggregation from file
   readWordAndValue(infile, "lenaggfile", aggfilename);
-  datafile.open(aggfilename, ios::in);
+  datafile.open(aggfilename, ios::binary);
   handle.checkIfFailure(datafile, aggfilename);
   handle.Open(aggfilename);
   numlen = readLengthAggregation(subdata, lengths, lenindex);
@@ -159,7 +159,7 @@ StockDistribution::StockDistribution(CommentStream& infile,
 
   //We have now read in all the data from the main likelihood file
   //But we have to read in the statistics data from datafilename
-  datafile.open(datafilename, ios::in);
+  datafile.open(datafilename, ios::binary);
   handle.checkIfFailure(datafile, datafilename);
   handle.Open(datafilename);
   readStockData(subdata, TimeInfo, numarea, numage, numlen);
@@ -168,13 +168,13 @@ StockDistribution::StockDistribution(CommentStream& infile,
   datafile.clear();
 
   switch (functionnumber) {
-    case 2:
+    case 2: // sumofsquares / stratified
       for (i = 0; i < numarea; i++) {
         modelYearData.resize(new DoubleMatrix(stocknames.Size(), (numage * numlen), 0.0));
         obsYearData.resize(new DoubleMatrix(stocknames.Size(), (numage * numlen), 0.0));
       }
       break;
-    case 1:
+    case 1: // multinomial
       if (yearly)
         handle.logMessage(LOGWARN, "Warning in stockdistribution - yearly aggregation is ignored for function", functionname);
       yearly = 0;
@@ -337,10 +337,10 @@ void StockDistribution::Reset(const Keeper* const keeper) {
     }
 
   switch (functionnumber) {
-    case 1:
+    case 1: // multinomial
       MN.setValue(epsilon);
       break;
-    case 2:
+    case 2: // sumofsquares / stratified
       break;
     default:
       handle.logMessage(LOGWARN, "Warning in stockdistribution - unrecognised function", functionname);
@@ -500,10 +500,10 @@ void StockDistribution::addLikelihood(const TimeClass* const TimeInfo) {
 
   double l = 0.0;
   switch (functionnumber) {
-    case 1:
+    case 1: // multinomial
       l = calcLikMultinomial();
       break;
-    case 2:
+    case 2: // sumofsquares / stratified
       l = calcLikSumSquares(TimeInfo);
       break;
     default:
