@@ -63,7 +63,7 @@ Tags::Tags(CommentStream& infile, const char* givenname, const AreaClass* const
 
   //read in the numbers format: tagid - length - number
   readWordAndValue(infile, "numbers", text);
-  subfile.open(text, ios::in);
+  subfile.open(text, ios::binary);
   handle.checkIfFailure(subfile, text);
   handle.Open(text);
   readNumbers(subcomment, givenname, TimeInfo);
